@@ -1,13 +1,15 @@
 from dataclasses import dataclass, asdict, astuple, fields, is_dataclass
 from typing import Any, Dict, Tuple
 
+
 class _Meta(type):
     def __new__(cls: Any, name: str, bases: Tuple[type], attrs: Dict[str, Any]):
         res = type.__new__(cls, name, bases, attrs)
-        if name != 'BaseDataClass':
+        if name != "BaseDataClass":
             res = dataclass(res)
         return res
 
+
 class BaseDataClass(metaclass=_Meta):
     """
     稍简化Python自带dataclasses用法
