@@ -1,11 +1,12 @@
 import os
 from ..string import zjoin
 import cv2
-from typing import Generator
+from typing import Iterator
+
 
 class ImageLoader:
 
-    def __init__(self, dir:str, exts=['.jpg','.jpeg','.png','.bmp'],recursive=False) -> None:
+    def __init__(self, dir: str, exts=[".jpg", ".jpeg", ".png", ".bmp", ".tif"], recursive=False) -> None:
         dir = os.path.abspath(dir)
         self.dir = dir
         self.exts = exts
@@ -17,18 +18,19 @@ class ImageLoader:
             if os.path.splitext(fname)[-1].lower() not in self.exts:
                 continue
             self.names.append(fname)
-            self.paths.append(zjoin(self.dir,fname))
+            self.paths.append(zjoin(self.dir, fname))
 
         self.recursive = recursive
 
     def walk(self):
         pass
 
-    def load(self,read=True)->Generator[str,str,cv2.typing.MatLike]:
-        for name, path in zip(self.names,self.paths):
+    def load(self, read=True) -> Iterator[tuple[str, str, cv2.typing.MatLike]]:
+        """
+        return name, path , cv2.imread(path)
+        """
+        for name, path in zip(self.names, self.paths):
             if read:
-                yield name, path , cv2.imread(path), 
+                yield name, path, cv2.imread(path)
             else:
-                yield name, path , None
-
-
+                yield name, path, None
